@@ -10,20 +10,20 @@ const AsyncParallelBailHook = require("../AsyncParallelBailHook");
 
 describe("AsyncParallelHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new AsyncParallelHook(args));
+		const tester = new HookTester(args => new AsyncParallelHook(args));
 
 		const result = await tester.run();
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
 
 describe("AsyncParallelBailHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new AsyncParallelBailHook(args));
+		const tester = new HookTester(args => new AsyncParallelBailHook(args));
 
 		const result = await tester.run();
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
