@@ -12,44 +12,68 @@ describe("Hook", () => {
 
 		const calls = [];
 		hook.tap("A", () => calls.push("A"));
-		hook.tap({
-			name: "B",
-			before: "A"
-		}, () => calls.push("B"));
+		hook.tap(
+			{
+				name: "B",
+				before: "A"
+			},
+			() => calls.push("B")
+		);
 
 		calls.length = 0;
 		hook.call();
 		expect(calls).toEqual(["B", "A"]);
 
-		hook.tap({
-			name: "C",
-			before: ["A", "B"]
-		}, () => calls.push("C"));
+		hook.tap(
+			{
+				name: "C",
+				before: ["A", "B"]
+			},
+			() => calls.push("C")
+		);
 
 		calls.length = 0;
 		hook.call();
 		expect(calls).toEqual(["C", "B", "A"]);
 
-		hook.tap({
-			name: "D",
-			before: "B"
-		}, () => calls.push("D"));
+		hook.tap(
+			{
+				name: "D",
+				before: "B"
+			},
+			() => calls.push("D")
+		);
 
 		calls.length = 0;
 		hook.call();
 		expect(calls).toEqual(["C", "D", "B", "A"]);
 
-		hook.tap({
-			name: "E",
-			stage: -5
-		}, () => calls.push("E"));
-		hook.tap({
-			name: "F",
-			stage: -3
-		}, () => calls.push("F"));
+		hook.tap(
+			{
+				name: "E",
+				stage: -5
+			},
+			() => calls.push("E")
+		);
+		hook.tap(
+			{
+				name: "F",
+				stage: -3
+			},
+			() => calls.push("F")
+		);
 
 		calls.length = 0;
 		hook.call();
 		expect(calls).toEqual(["E", "F", "C", "D", "B", "A"]);
 	});
+	it("should throw without a valid name", () => {
+		const hook = new SyncHook();
+		expect(() => hook.tap("", () => {})).toThrow(
+			new Error("Missing name for tap")
+		);
+		expect(() => hook.tap(" ", () => {})).toThrow(
+			new Error("Missing name for tap")
+		);
+	});
 });
