@@ -12,40 +12,40 @@ const SyncLoopHook = require("../SyncLoopHook");
 
 describe("SyncHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new SyncHook(args));
+		const tester = new HookTester(args => new SyncHook(args));
 
 		const result = await tester.run(true);
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
 
 describe("SyncBailHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new SyncBailHook(args));
+		const tester = new HookTester(args => new SyncBailHook(args));
 
 		const result = await tester.run(true);
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
 
 describe("SyncWaterfallHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new SyncWaterfallHook(args));
+		const tester = new HookTester(args => new SyncWaterfallHook(args));
 
 		const result = await tester.run(true);
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
 
 describe("SyncLoopHook", () => {
 	it("should have to correct behavior", async () => {
-		const tester = new HookTester((args) => new SyncLoopHook(args));
+		const tester = new HookTester(args => new SyncLoopHook(args));
 
 		const result = await tester.runForLoop(true);
 
 		expect(result).toMatchSnapshot();
-	}, 15000)
-})
+	}, 15000);
+});
